<?php

namespace Drupal\mixpanel;

use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Mixpanel client service.
 */
class MixpanelClient {

  /**
   * A configured Mixpanel client.
   *
   * @var \Mixpanel
   */
  protected $client;

  /**
   * Constructs a MixpanelClient object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   */
  public function __construct(protected ConfigFactoryInterface $configFactory) {
  }

  /**
   * Get the mixpanel client.
   *
   * @return \Mixpanel
   *   The mixpanel client.
   */
  public function getClient(): \Mixpanel {
    if ($this->client) {
      return $this->client;
    }

    $settings = $this->configFactory->get('mixpanel.settings');
    $projectToken = $settings->get('project_token');
    $options = [];
    if ($host = $settings->get('host')) {
      $options['host'] = $host;
    }
    if ($settings->get('debug')) {
      $options['debug'] = TRUE;
    }
    $this->client = \Mixpanel::getInstance($projectToken, $options);

    return $this->client;
  }

}
