<?php

namespace Drupal\Tests\mixpanel\FunctionalJavascript;

use Drupal\FunctionalJavascriptTests\WebDriverTestBase;

/**
 * Tests that the Mixpanel project settings are found in drupalSettings.
 *
 * @group mixpanel
 */
class MixpanelJavaScriptTest extends WebDriverTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['mixpanel'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Tests that the project token is correctly set in drupalSettings.
   */
  public function testProjectTokenInDrupalSettings() {
    // Set a test project token in the Mixpanel settings.
    $test_token = 'test_project_token';
    $this->config('mixpanel.settings')
      ->set('project_token', $test_token)
      ->save();

    // Visit the front page.
    $this->drupalGet('<front>');

    // Get the drupalSettings from the page.
    $drupal_settings = $this->getDrupalSettings();

    // Assert that the project token is correctly set in drupalSettings.
    $this->assertArrayHasKey('mixpanel', $drupal_settings);
    $this->assertArrayHasKey('project_token', $drupal_settings['mixpanel']);
    $this->assertEquals($test_token, $drupal_settings['mixpanel']['project_token']);

    // Assert that debug mode is set to FALSE by default in drupalSettings.
    $this->assertArrayHasKey('debug', $drupal_settings['mixpanel']);
    $this->assertFalse($drupal_settings['mixpanel']['debug']);

    // Test that the token can be accessed via JavaScript.
    $token_from_js = $this->getSession()->evaluateScript('return drupalSettings.mixpanel.project_token');
    $this->assertEquals($test_token, $token_from_js);

    // Test that debug mode can be accessed via JavaScript and is FALSE by
    // default.
    $debug_from_js = $this->getSession()->evaluateScript('return drupalSettings.mixpanel.debug');
    $this->assertFalse($debug_from_js);
  }

  /**
   * Tests that debug mode is correctly set in drupalSettings when enabled.
   */
  public function testDebugModeInDrupalSettings() {
    // Set a test project token and enable debug mode in the Mixpanel settings.
    $test_token = 'test_project_token';
    $this->config('mixpanel.settings')
      ->set('project_token', $test_token)
      ->set('debug', TRUE)
      ->save();

    // Visit the front page.
    $this->drupalGet('<front>');

    // Get the drupalSettings from the page.
    $drupal_settings = $this->getDrupalSettings();

    // Assert that debug mode is correctly set to TRUE in drupalSettings.
    $this->assertArrayHasKey('mixpanel', $drupal_settings);
    $this->assertArrayHasKey('debug', $drupal_settings['mixpanel']);
    $this->assertTrue($drupal_settings['mixpanel']['debug']);

    // Test that debug mode can be accessed via JavaScript and is TRUE.
    $debug_from_js = $this->getSession()->evaluateScript('return drupalSettings.mixpanel.debug');
    $this->assertTrue($debug_from_js);
  }

}
